function Y = getImage(matrice,li,col,noimg)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%convert a vector to a matrix
%%inputs:
%matrice: matrice within in line is an image
%li: number of lines in the image
%col: number of columns in the image
%noimg: index of the line of matrice you want to convert in 2D image
%%output:
%Y: 2D matrixe from the designed vector in matrice
%%exemple:
%getImage([1 1 1 1;2 2 2 2;3 3 3 3],2,2,2)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Y = vec2img(matrice(noimg,:),col,li);